:orphan:

Example Programs
================

Play a Sound File
-----------------

:download:`play_file.py <../examples/play_file.py>`

.. literalinclude:: ../examples/play_file.py

Play a Very Long Sound File
---------------------------

:download:`play_long_file.py <../examples/play_long_file.py>`

.. literalinclude:: ../examples/play_long_file.py

Input to Output Pass-Through
----------------------------

:download:`wire.py <../examples/wire.py>`

.. literalinclude:: ../examples/wire.py

Plot Microphone Signal(s) in Real-Time
--------------------------------------

:download:`plot_input.py <../examples/plot_input.py>`

.. literalinclude:: ../examples/plot_input.py

Real-Time Text-Mode Spectrogram
-------------------------------

:download:`spectrogram.py <../examples/spectrogram.py>`

.. literalinclude:: ../examples/spectrogram.py

Recording with Arbitrary Duration
---------------------------------

:download:`rec_unlimited.py <../examples/rec_unlimited.py>`

.. literalinclude:: ../examples/rec_unlimited.py
